summaryrefslogtreecommitdiffstats
path: root/src/H5Ffake.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Ffake.c')
-rw-r--r--src/H5Ffake.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/H5Ffake.c b/src/H5Ffake.c
index 86c4a3d..d199cf0 100644
--- a/src/H5Ffake.c
+++ b/src/H5Ffake.c
@@ -15,10 +15,11 @@
/* Packages needed by this file... */
-#include "H5private.h" /* Generic Functions */
-#include "H5Eprivate.h" /* Error handling */
-#include "H5Iprivate.h" /* IDs */
-#include "H5Fpkg.h" /* File access */
+#include "H5private.h" /* Generic Functions */
+#include "H5Eprivate.h" /* Error handling */
+#include "H5Fpkg.h" /* File access */
+#include "H5Iprivate.h" /* IDs */
+#include "H5Pprivate.h" /* Property lists */
/* PRIVATE PROTOTYPES */
@@ -45,7 +46,6 @@ H5F_fake_alloc(uint8_t sizeof_size, hid_t fapl_id)
{
H5F_t *f = NULL; /* Pointer to fake file struct */
H5P_genplist_t *plist; /* Property list */
- hbool_t latest;
H5F_t *ret_value = NULL; /* Return value */
FUNC_ENTER_NOAPI(NULL)
@@ -62,15 +62,15 @@ H5F_fake_alloc(uint8_t sizeof_size, hid_t fapl_id)
else
f->shared->sizeof_size = sizeof_size;
/* Activate latest version support according to the setting in fapl_id */
/* See H5F_new() in H5Fint.c */
if(NULL == (plist = (H5P_genplist_t *)H5I_object(fapl_id)))
HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, NULL, "not file access property list")
- if(H5P_get(plist, H5F_ACS_LATEST_FORMAT_NAME, &latest) < 0)
- HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, NULL, "can't get 'latest format' flag")
- if(latest)
- f->shared->latest_flags |= H5F_LATEST_ALL_FLAGS;
+ if(H5P_get(plist, H5F_ACS_LIBVER_LOW_BOUND_NAME, &(f->shared->low_bound)) < 0)
+ HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, NULL, "can't get 'low' bound for library format versions")
+ if(H5P_get(plist, H5F_ACS_LIBVER_HIGH_BOUND_NAME, &(f->shared->high_bound)) < 0)
+ HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, NULL, "can't get 'high' bound for library format versions")
/* Set return value */
ret_value = f;
@@ -62,15 +62,15 @@ H5F_fake_alloc(uint8_t sizeof_size, hid_t fapl_id)
else
f->shared->sizeof_size = sizeof_size;
- /* Activate latest version support according to the setting in fapl_id */
+ /* Set low/high bounds according to the setting in fapl_id */
/* See H5F_new() in H5Fint.c */
if(NULL == (plist = (H5P_genplist_t *)H5I_object(fapl_id)))